# AWS Cost Mutilator
## It's what accounting craves.  

### Installation:
```shell
pip install aws-cost-mutilator
```


### Usage:
```shell
acm [OPTIONS] COMMAND [ARGS]...

Options:
  -p, --profile TEXT  AWS profile
  -r, --region TEXT   AWS region
  --help              Show this message and exit.

Commands:
  check
  clean
```
